@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,13 +24,9 @@
 Importing Commands
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import sys
 import logging
 
-import six
-
 from rattail.commands.core import Subcommand, date_argument
 from rattail.config import parse_list
 from rattail.util import load_object
@@ -489,7 +485,7 @@ class ImportVersions(ImportRattail):
 
     def add_parser_args(self, parser):
         super(ImportVersions, self).add_parser_args(parser)
-        parser.add_argument('--comment', '-m', type=six.text_type, default=self.default_comment,
+        parser.add_argument('--comment', '-m', type=str, default=self.default_comment,
                             help="Comment to be recorded with the transaction.  "
                             "Default is \"{}\".".format(self.default_comment))
 
@@ -592,33 +588,36 @@ class PurgeVersions(VersionSubcommand):
         """
         Purge version data for all given models.
         """
+        import sqlalchemy as sa
+
         models = self.collect_models()
         if not models:
             log.warning("i have no models to purge!")
             return
 
-        for name, cls in sorted(six.iteritems(models)):
+        for name, cls in sorted(models.items()):
             self.purge_version_data(session, cls)
 
         self.stdout.write("purged all data for {} version tables\n".format(len(models)))
 
         log.debug("will now purge data for transaction_meta table")
-        session.execute('truncate "transaction_meta"')
+        session.execute(sa.text('truncate "transaction_meta"'))
         log.debug("will now purge data for transaction table")
-        session.execute('truncate "transaction"')
+        session.execute(sa.text('truncate "transaction"'))
         self.stdout.write("purged all data for 2 transaction tables\n")
 
     def purge_version_data(self, session, cls):
         """
         Purge version data for the given model class.
         """
+        import sqlalchemy as sa
         import sqlalchemy_continuum as continuum
 
         vcls = continuum.version_class(cls)
         vtable = vcls.__table__
 
         log.debug("will now purge data for version table: %s", vtable.name)
-        session.execute('truncate "{}"'.format(vtable.name))
+        session.execute(sa.text('truncate "{}"'.format(vtable.name)))
         self.stdout.write("purged data for: {}\n".format(vtable.name))
 
 
@@ -658,7 +657,7 @@ class VersionCheck(VersionSubcommand):
         all_models = self.collect_models()
         if requested:
             models = dict([(k, v)
-                           for k, v in six.iteritems(all_models)
+                           for k, v in all_models.items()
                            if k in requested])
         else:
             models = all_models
@@ -666,7 +665,7 @@ class VersionCheck(VersionSubcommand):
             log.warning("i have no models to check!")
             return
 
-        for name, cls in sorted(six.iteritems(models)):
+        for name, cls in sorted(models.items()):
             self.check_versions(session, cls)
 
         log.info("checked version data for %s models", len(models))
