@@ -34,7 +34,7 @@ from traceback import format_exception
 from rattail.daemon import Daemon
 from rattail.threads import Thread
 from rattail.datasync.config import load_profiles
-from rattail.datasync.util import get_lastrun, get_lastrun_setting, get_lastrun_timefmt, next_batch_id
+from rattail.datasync.util import next_batch_id
 
 
 log = logging.getLogger(__name__)
@@ -124,14 +124,15 @@ def watch_for_changes(config, watcher):
     :param watcher: Reference to datasync watcher object.
     """
     app = config.get_app()
+    datasync_handler = app.get_datasync_handler()
 
     # let watcher do any setup it needs
     watcher.setup()
 
     # the 'last run' value is maintained as zone-aware UTC
-    lastrun = get_lastrun(config, watcher.key)
-    lastrun_setting = get_lastrun_setting(config, watcher.key)
-    timefmt = get_lastrun_timefmt(config)
+    lastrun = datasync_handler.get_watcher_lastrun(watcher.key)
+    lastrun_setting = datasync_handler.get_watcher_lastrun_setting(watcher.key)
+    timefmt = datasync_handler.get_lastrun_timefmt()
 
     # outer loop - this should never terminate unless an unhandled
     # exception happens, or the daemon is stopped
