@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,8 @@
 DataSync for Rattail
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import logging
 
-import six
 from sqlalchemy import orm
 
 from rattail.db.util import make_topo_sortkey
@@ -151,7 +148,7 @@ class RattailWatcher(DataSyncWatcher):
         try:
             for key in keys:
                 if key: # note that key can sometimes be None
-                    change = session.query(model.Change).get(key)
+                    change = session.get(model.Change, key)
                     if change:
                         session.delete(change)
                         session.flush()
@@ -230,7 +227,7 @@ class RattailConsumer(DataSyncConsumer):
                     change.payload_type, change.payload_key))
 
                 if change.deletion:
-                    instance = session.query(cls).get(change.payload_key)
+                    instance = session.get(cls, change.payload_key)
                     if instance:
                         self.delete_instance(session, instance)
                         session.flush()
@@ -238,7 +235,7 @@ class RattailConsumer(DataSyncConsumer):
                         log.warning("could not find instance to delete")
 
                 else: # add/update
-                    host_instance = host_session.query(cls).get(change.payload_key)
+                    host_instance = host_session.get(cls, change.payload_key)
                     if host_instance:
 
                         # if processing a pack item, must process its unit item
@@ -424,7 +421,7 @@ class FromRattailToRattailBase(DataSyncImportConsumer):
             cls = self.model.Product
         else:
             cls = getattr(self.model, change.payload_type)
-        return session.query(cls).get(change.payload_key)
+        return session.get(cls, change.payload_key)
 
 
 class FromRattailToRattailExportConsumer(FromRattailToRattailBase):
@@ -464,7 +461,7 @@ class FromRattailToRattailExportConsumer(FromRattailToRattailBase):
             self.target_session.set_continuum_user(self.runas_username)
 
         # update all importers with current sessions
-        for importer in six.itervalues(self.importers):
+        for importer in self.importers.values():
             importer.host_session = self.local_session
             importer.session = self.target_session
 
