@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,16 +24,12 @@
 Data Models for Contact Info
 """
 
-from __future__ import unicode_literals, absolute_import
-
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 
 from .core import Base, uuid_column
 
 
-@six.python_2_unicode_compatible
 class PhoneNumber(Base):
     """
     Represents a phone (or fax) number associated with a contactable entity.
@@ -61,7 +57,6 @@ class PhoneNumber(Base):
         return self.preference == 1
 
 
-@six.python_2_unicode_compatible
 class EmailAddress(Base):
     """
     Represents an email address associated with a contactable entity.
@@ -94,7 +89,6 @@ class EmailAddress(Base):
         return self.preference == 1
 
 
-@six.python_2_unicode_compatible
 class MailingAddress(Base):
     """
     Represents a physical / mailing address associated with a contactable entity.
@@ -214,7 +208,7 @@ class ContactMixin(object):
             session = orm.object_session(self)
             contact = email.parent
             if not contact:
-                contact = session.query(email.Parent).get(email.parent_uuid)
+                contact = session.get(email.Parent, email.parent_uuid)
                 if not contact:
                     raise ValueError("cannot locate parent {} contact for email: {}".format(
                         email.Parent.__name__, email))
@@ -294,7 +288,7 @@ class ContactMixin(object):
             session = orm.object_session(self)
             contact = phone.parent
             if not contact:
-                contact = session.query(phone.Parent).get(phone.parent_uuid)
+                contact = session.get(phone.Parent, phone.parent_uuid)
                 if not contact:
                     raise ValueError("cannot locate parent {} contact for phone: {}".format(
                         phone.Parent.__name__, phone))
@@ -341,7 +335,7 @@ class ContactMixin(object):
             session = orm.object_session(self)
             contact = address.parent
             if not contact:
-                contact = session.query(address.Parent).get(address.parent_uuid)
+                contact = session.get(address.Parent, address.parent_uuid)
                 if not contact:
                     raise ValueError("cannot locate parent {} contact for address: {}".format(
                         address.Parent.__name__, address))
