@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Database Utilities
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import re
 import pprint
 import logging
@@ -59,8 +57,9 @@ class CounterMagic(object):
         table = sa.Table('counter_{}'.format(key), self.metadata,
                          sa.Column('value', sa.Integer(), primary_key=True))
         table.create(engine, checkfirst=True)
-        result = engine.execute(table.insert())
-        return result.lastrowid
+        with engine.begin() as cxn:
+            result = cxn.execute(table.insert())
+            return result.lastrowid
 
 
 class QuerySequence(object):
