@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Mail Monitor Actions
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 import shutil
 import tempfile
@@ -81,7 +79,8 @@ def download_message(server, msg_uid, output_dir, locking=False):
     response, msg_body = msg_data[0]
 
     # figure out where we need to write the file
-    filename = '{}.eml'.format(msg_uid)
+    # nb. msg_uid is bytes, must convert
+    filename = '{}.eml'.format(msg_uid.decode('utf_8'))
     if locking:
         tempdir = tempfile.mkdtemp()
         path = os.path.join(tempdir, filename)
