@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Upgrade handlers
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 import shutil
 import subprocess
@@ -64,7 +62,7 @@ class UpgradeHandler(GenericHandler):
         systems.insert(0, {
             'key': 'rattail',
             'label': self.config.app_title(),
-            'command': self.config.require('rattail.upgrades', 'command'),
+            'command': self.config.get('rattail.upgrades', 'command'),
         })
 
         return systems
